@@ -72,19 +72,34 @@ plot_RLum.Results<- structure(function(#Plot function for an RLum.Results S4 cla
     
     ## single MAM estimate
     # plot profile log likelhood
-    try(
-      plot(data@data$profile, show.points=FALSE, plot.confstr=TRUE, onepage = single, ask = FALSE)
-    )
-
+    tryCatch({
+      suppressWarnings(
+        bbmle::plot(data@data$profile, show.points=FALSE, plot.confstr=TRUE, onepage = single, ask = FALSE)
+      )
+    }, error = function(e) {
+      if (single) 
+        par(mfrow=c(2, 2))
+      param <- c("gamma", "sigma", "p0", "mu")
+      for (i in param) {
+        if (data@data$summary$par == 3 && i == "mu") 
+          break
+        tryCatch({
+          bbmle::plot(data@data$profile, which = i)
+        }, error = function(e)  {
+          message(paste("Unable to plot the Likelihood profile for:", i))
+        })
+      }
+      par(mfrow=c(1,1))
+    })
+    
     ## bootstrap MAM estimates
     if(data@data$args$bootstrap==TRUE) {
-
+      
       # save previous plot parameter and set new ones
       .pardefault<- par(no.readonly = TRUE)
       
       # get De-llik pairs
       pairs<- data@data$bootstrap$pairs$gamma
-      p0.pairs<- data@data$bootstrap$pairs$p0
       
       # get polynomial fit objects
       poly.lines<- list(poly.three=data@data$bootstrap$poly.fits$poly.three,
@@ -120,12 +135,6 @@ plot_RLum.Results<- structure(function(#Plot function for an RLum.Results S4 cla
         # remove invalid NA values
         pairs<- na.omit(pairs)
         
-        # sort corresponding p0 values
-        p0.pairs<- p0.pairs[order(p0.pairs[,1]),]
-        
-        # remove invalid NA values
-        p0.pairs<- na.omit(p0.pairs)
-        
         plot(x=pairs[,1], 
              y=pairs[,2],
              xlab="Equivalent Dose [Gy]",
@@ -175,7 +184,7 @@ plot_RLum.Results<- structure(function(#Plot function for an RLum.Results S4 cla
         
         # set margins (bottom, left, top, right)
         par(mar=c(5,5,0,3))
-
+        
         plot(x = pairs[,1],
              y = residuals(poly.lines[[i]]),
              ylim = c(min(residuals(poly.lines[[i]]))*1.2,
@@ -865,7 +874,7 @@ plot_RLum.Results<- structure(function(#Plot function for an RLum.Results S4 cla
     if(data@data$args$MC == TRUE) {
       
       extraArgs <- list(...)
-
+      
       main<- if("main" %in% names(extraArgs)) { extraArgs$main } else { "Monte Carlo Simulation"  }
       xlab<- if("xlab" %in% names(extraArgs)) { extraArgs$xlab } else { "Amount of grains on aliquot" }
       
@@ -958,7 +967,7 @@ plot_RLum.Results<- structure(function(#Plot function for an RLum.Results S4 cla
   data(ExampleData.DeValues, envir = environment())
   
   # apply the un-logged minimum age model
-  mam<- calc_MinDose(data = ExampleData.DeValues, sigmab = 0.2, log = FALSE, plot = FALSE)
+  mam<- calc_MinDose(data = ExampleData.DeValues$CA1, sigmab = 0.2, log = TRUE, plot = FALSE)
   
   ##plot
   plot_RLum.Results(mam)
